#!/bin/sh
#
# This is a driver installer for IRTOUCH Touch Screen.
#
# Company: Beijing IRTOUCH SYSTEMS Co.,Ltd
# Version: 3.0.0
# Released: 10/31/2016
#

version="3.0.0"
driverName="irtouch.bin.tar.gz"
companyName="irtouch"
installPath="/usr/local"

localPath="/etc/rc.d/rc.local"
localPath1="/etc/rc.local"
localPath2="/etc/boot.local"

uinputpath="/dev/uinput"
servicePath="/usr/local/irtouch/irtouch.init"
servicePath1="/usr/local/irtouch/irtouch/irtouch.sh"
tsConfigName="irtouch/irtouch.conf"
localConfig="irtouch.conf"
saveConfigPath="/etc"
SERVICE="irtouchServer"
lightdmConf="60-irtouch.conf"

ShowTitle() {
    echo ""
    echo "#######################################################"
    echo "#                                                     #"
    echo "#          Beijing IRTOUCH SYSTEMS Co.,Ltd            #"
    echo "#                                                     #"
    echo "#         Linux driver installer for IRTOUCH          #"
    echo "#                                                     #"
    echo "#######################################################"
    echo ""
}

CheckPermission() {
    echo  -n "(I) Check user permission:"
    account=`whoami`
    if [ ${account} = "root" ]; then
        echo " ${account}, you are the supervisor."
		if [ -e ${uinputpath} ]; then
			echo ""
		else
			modprobe uinput
			if [ -e ${uinputpath} ]; then
				echo ""
			else
				echo "(E) Failed to intall driver and don't hesitate to contact us."
				exit 1
			fi
		fi
    else
		echo " (E) ${account}, you are NOT the supervisor."
        echo "(E) The root permission is required to run this installer."
        echo ""
        exit 1
    fi
}

ExtractDriver() {
    if [ -e ${installPath}/${driverName} ]; then
        rm -f ${installPath}/${driverName}
    fi
    
    if [ -e ${installPath}/${companyName} ]; then
        rm -rf ${installPath}/${companyName}
        echo "(I) Found and removed previous IRTOUCH driver."
    fi

    cp -f ${driverName} ${installPath}
    ( cd ${installPath}; tar -zxf ${driverName}; rm -f ${driverName} )
    temppath=`find ${installPath} -name ${companyName}`
    #driverpath=${temppath%/*}
 	echo "(I) Extract IRTOUCH driver archive to /usr/local/irtouch."
 	cp -af ${installPath}/${companyName}/${companyName} ${saveConfigPath}
	if [ -s `pwd`/${localConfig} ]; then
		cp `pwd`/${localConfig} ${saveConfigPath}/${tsConfigName}
	fi

    echo "(I) Copy configuration file to /etc."

	ln -sf /usr/local/irtouch/irtouch_match_monitor /usr/bin
	echo "(I) Create irtouch_match_monitor in /usr/bin"


   # ln -sf ${installPath}/${companyName}/calib /usr/bin
   # echo "(I) Create calib link in /usr/bin."
}

RemoveDriver() {
    if [ -e ${installPath}/${driverName} ]; then	
        rm -rf ${installPath}/${driverName}
    fi
	
    temppath=`find ${installPath} -name ${companyName}`
    driverpath=${temppath%/*}
    if [ -z "${driverpath}" ]; then
        echo "(E) The driver archive has been removed already."
        echo ""
        exit 1
    elif [ -e ${installPath}/${companyName} ]; then
	${installPath}/${companyName}/irtouch.init stop
	rm -rf ${installPath}/${companyName}
	echo "(I) Removed IRTOUCH driver archive from ${installPath}/${companyName}."
    fi
}


gdmFile="/etc/gdm/Init/Default"
lightdmDir2="/etc/lightdm/"
lightdmDir1="/usr/share/lightdm/lightdm.conf.d"
EditLoginFile(){
	if [ -w ${gdmFile} ]; then
		grep -q $servicePath ${gdmFile}
        if [ $? -eq 1 ]; then
			 sed -i '/exit 0/d' ${gdmFile}
             filelines=`cat ${gdmFile} | wc -l`
             echo "(I) Add irtouch Service $1 into ${gdmFile}."
             sed -i ''${filelines}'a\# added by IRTOUCH installer\n'$servicePath' restart &\n\nexit 0' ${gdmFile}
        else
             echo "(I) The $servicePath has been added in ${gdmFile}."
        fi
	fi

	if [ -e ${lightdmDir1} ]; then
			echo "(I) Copy  ${installPath}/${companyName}/irtouch/${lightdmConf} to ${lightdmDir1}"
		cp ${installPath}/${companyName}/irtouch/${lightdmConf} ${lightdmDir1}
	elif [ -e ${lightdmDir2} ]; then
			if [ -w ${lightdmDir2}/lightdm.conf ]; then
				grep -q ${servicePath1} ${lightdmDir2}/lightdm.conf
				if [ $? -eq 1 ]; then
					filelines=`cat ${lightdmDir2}/lightdm.conf | wc -l`
					echo "(I) Add irtouch Service $1 into ${lightdmDir2}/lightdm.conf."
					sed -i ''${filelines}'a\# added by IRTOUCH installer\ndisplay-setup-script='${servicePath1}'' ${lightdmDir2}/lightdm.conf 
				else
             		echo "(I) The $servicePath1 has been added in ${lightdmDir2}/lightdm.conf."
				fi
			else
				echo "(I) Copy ${installPath}/${companyName}/irtouch/${lightdmConf} to ${lightdmDir2}/lightdm.conf"
				cp ${installPath}/${companyName}/irtouch/${lightdmConf} ${lightdmDir2}/lightdm.conf
			fi
	fi

}

RemoveLoginFile() {
	if [ -w ${gdmFile} ]; then
        grep -q $servicePath ${gdmFile}
        if [ $? -eq 0 ]; then
             sed -i '/# added by IRTOUCH installer/,/restart &/d' ${gdmFile}
             echo "(I) Removed $servicePath from ${gdmFile}."
        fi
	fi
	
	if [ -e ${lightdmDir1}/${lightdmConf} ]; then
			echo "(I) rm ${lightdmDir1}/${lightdmConf}"
		rm "${lightdmDir1}/${lightdmConf}"
	fi
	if [ -e ${lightdmDir2}/lightdm.conf ]; then
		grep -q ${servicePath1} ${lightdmDir2}/lightdm.conf
		if [ $? -eq 0 ]; then
			echo "(I) Removed ${servicePath1} from ${lightdmDir2}/lightdm.conf."
			sed -i '/# added by IRTOUCH installer/,/irtouch.sh /d' ${lightdmDir2}/lightdm.conf
		fi
	fi
}

EditLocalFile() {
    if [ -w ${localPath} ]; then
		grep -q $servicePath ${localPath}
        if [ $? -eq 1 ]; then
			sed -i '/exit 0/d' ${localPath}
             filelines=`cat ${localPath} | wc -l`
             echo "(I) Add irtouch Service $1 into ${localPath}."
             sed -i ''${filelines}'a\# added by IRTOUCH installer\n'$servicePath' start &' ${localPath}
        else
             echo "(I) The $servicePath has been added in ${localPath}."
        fi
    elif [ -w ${localPath1} ]; then
		grep -q $servicePath ${localPath1}
		if [ $? -eq 1 ]; then
		sed -i '/exit 0/d' ${localPath1}
			filelines=`cat ${localPath1} | wc -l`
             echo "(I) Add irtouch Service $1 into ${localPath1}."
             sed -i ''${filelines}'a\# added by IRTOUCH installer\n'$servicePath' start &\n\nexit 0' ${localPath1}
        else
             echo "(I) The $servicePath has been added in ${localPath1}."
        fi
    elif [ -w ${localPath2} ]; then
        grep -q $servicePath ${localPath2}
         if [ $? -eq 1 ]; then
	     sed -i '/exit 0/d' ${localPath2}
             filelines=`cat ${localPath2} | wc -l`
             echo "(I) Add irtouch Service $1 into ${localPath2}."
             sed -i ''${filelines}'a\# added by IRTOUCH installer\n'$servicePath' start &\n\nexit 0' ${localPath2}
        else
             echo "(I) The $servicePath has been added in ${localPath2}."
        fi
    else
		#echo "(E) No rc.local or boot.local file found."
		cp ${installPath}/${companyName}/irtouch/rc.local ${localPath}
    fi

	#EditLoginFile

}
RemoveLocalFile() {
    if [ -w ${localPath} ]; then
        grep -q $servicePath ${localPath}
        if [ $? -eq 0 ]; then
             sed -i '/# added by IRTOUCH installer/,/start &/d' ${localPath}
             echo "(I) Removed $servicePath from ${localPath}."
        fi
    elif [ -w ${localPath1} ]; then
        grep -q $servicePath ${localPath1}
         if [ $? -eq 0 ]; then
             sed -i '/# added by IRTOUCH installer/,/start &/d' ${localPath1}
             echo "(I) Remove $servicePath from ${localPath1}."
        fi
    elif [ -w ${localPath2} ]; then
        grep -q $servicePath ${localPath2}
         if [ $? -eq 0 ]; then
             sed -i '/# added by IRTOUCH installer/,/start &/d' ${localPath2}
             echo "(I) Remove $servicePath from ${localPath2}."
        fi
    else
	echo "(E) No rc.local or boot.local file found."
    fi

	RemoveLoginFile
}


RemoveConfigFile() {
    if [ -e ${saveConfigPath}/${tsConfigName} ]; then
	rm -rf ${saveConfigPath}/${companyName}
    	echo "(I) Remove configuration file from /etc."
    else
       	echo "(I) No configuration file from /etc found."
    fi
}

CheckOldDriver() {
    temppath=`find ${installPath} -name ${companyName}`
    olddriverpath=${temppath%/*}
    if [ -z "${olddriverpath}" ]; then
        echo "(I) Begin to setup the IRTOUCH driver."
    else
		echo "(I) Found the old IRTOUCH driver and will remove it."
       # echo "(E) It has to be removed before run ithis installer."
		RemoveDriver
		RemoveConfigFile
		RemoveLocalFile
		echo "[I] The old IRTOUCH driver have removed."
    fi
}



clear
ShowTitle

if [ $# = 0 ]; then
    CheckPermission
    CheckOldDriver
    ExtractDriver
    EditLocalFile

#    rm /bin/sh
#   ln -s /bin/bash /bin/sh
#	${installPath}/${companyName}/irtouch.init start &
	irtouch_match_monitor
	sleep 5
	if ps -ef | grep -v grep | grep ${SERVICE} >/dev/null
	then
		echo " "
		echo "(I) The IRTOUCH Touch Screen driver has been installed successfully."
	else
		echo ""
		echo "(E) Fatal error and will unloading driver."
		RemoveDriver
		RemoveConfigFile
		RemoveLocalFile
		echo "(E) ${SERVICE} can not run and don't hesitate to contact us."
	fi

elif [ $# = 1 ]; then
    if [ $1 = "uninstall" ]; then
        CheckPermission
        echo "(I) Begin to remove IRTOUCH driver."
        RemoveDriver
		RemoveConfigFile
		RemoveLocalFile
        echo ""
        echo "(I) The IRTOUCH Touch Screen driver has been removed successfully."
    elif [ $1 = "version" ]; then
        echo "(I) Version: ${version}"
    else
        echo "(I) Usage: [sh $0] to install IRTOUCH Touch Screen driver."
	echo "           [sh $0 uninstall] to uninstall IRTOUCH Touch Screen driver."
    fi
else
    echo "(I) Usage: [sh $0] to install IRTOUCH Touch Screen driver."
    echo "           [sh $0 uninstall] to uninstall IRTOUCH Touch Screen driver."
fi
echo ""
